@@ -830,9 +830,11 @@ class Builder(Update):
             for pkg in InstalledPackageInfo.get_install_packages(var_db_path):
                 try:
                     if pkg['repository'] not in map_rep:
+                        b = pkg['repository']
                         yield pkg.atom
                     elif pkg != EbuildInfo(pkg.atom,
                                            map_rep[pkg['repository']]):
+                        a = EbuildInfo(pkg.atom, map_rep[pkg['repository']])
                         yield pkg.atom
                 except EbuildInfoError:
                     pass
