@@ -57,10 +57,12 @@ class ClBuilderProfileAction(Action):
                    'cl_builder_profile_url,cl_builder_profile_branch,'
                    'cl_builder_profile_storage)',
          'message': __("Repository transfer"),
-         'condition': lambda Get: not (
-             Get('cl_builder_profile_storage').is_local(
+         'condition': lambda Get: (Get('cl_builder_profile_url')
+                and not (
+                Get('cl_builder_profile_storage').is_local(
                  Get('cl_builder_profile_url'),
-                 Get('cl_builder_profile_branch')))
+                 Get('cl_builder_profile_branch'))))
+
          },
         {'name': 'reconfigure_vars1',
          'method': 'Builder.invalidateVariables("cl_builder_profile_storage")',
@@ -82,39 +84,39 @@ class ClBuilderProfileAction(Action):
          'message': __("Remove the {eachvar:capitalize} repository"),
          'method': 'Builder.remove_repositories(eachvar)'
          },
-        {'name': 'reps_synchronization',
-         'group': __("Repositories synchronization"),
-         'tasks': [
-             {'name': 'sync_reps',
-              'foreach': 'cl_builder_profile_sync_rep',
-              'message': __("Checking the {eachvar:capitalize} repository"),
-              'method': 'Builder.syncRepositories(eachvar)',
-              },
-             {'name': 'regen_cache',
-              'foreach': 'cl_builder_sync_overlay_rep',
-              'essential': False,
-              'method': 'Builder.regenCache(eachvar)',
-              },
-             {'name': 'eix_update',
-              'message': __("Updating the eix cache for "
-                            "{cl_builder_eix_repositories}"),
-              'method': 'Builder.eixUpdate(cl_builder_repository_name)',
-              },
-             # save
-             {'name': 'save',
-              'method': 'Builder.save_build(cl_builder_build,'
-                        'cl_builder_profile_datavars)',
-              },
-             # сообщение удачного завершения при обновлении репозиториев
-             {'name': 'success_syncrep',
-              'message': __("Synchronization finished"),
-              'depend': (Tasks.success() & Tasks.has_any("sync_reps",
-                                                         "sync_other_reps",
-                                                         "emerge_metadata",
-                                                         "eix_update")),
-              }
-         ]
-         },
+        # {'name': 'reps_synchronization',
+        #  'group': __("Repositories synchronization"),
+        #  'tasks': [
+        #      {'name': 'sync_reps',
+        #       'foreach': 'cl_builder_profile_sync_rep',
+        #       'message': __("Checking the {eachvar:capitalize} repository"),
+        #       'method': 'Builder.syncRepositories(eachvar)',
+        #       },
+        #      {'name': 'regen_cache',
+        #       'foreach': 'cl_builder_sync_overlay_rep',
+        #       'essential': False,
+        #       'method': 'Builder.regenCache(eachvar)',
+        #       },
+        #      {'name': 'eix_update',
+        #       'message': __("Updating the eix cache for "
+        #                     "{cl_builder_eix_repositories}"),
+        #       'method': 'Builder.eixUpdate(cl_builder_repository_name)',
+        #       },
+        #      # save
+        #      {'name': 'save',
+        #       'method': 'Builder.save_build(cl_builder_build,'
+        #                 'cl_builder_profile_datavars)',
+        #       },
+        #      # сообщение удачного завершения при обновлении репозиториев
+        #      {'name': 'success_syncrep',
+        #       'message': __("Synchronization finished"),
+        #       'depend': (Tasks.success() & Tasks.has_any("sync_reps",
+        #                                                  "sync_other_reps",
+        #                                                  "emerge_metadata",
+        #                                                  "eix_update")),
+        #       }
+        #  ]
+        #  },
         {'name': 'reps_synchronization',
          'group': __("Setting up the profile"),
          'tasks': [
